'********************************************************************
' Author: Paul Heasley
' Website: www.phdesign.com.au
' Copyright (C) 2006 Paul Heasley 
' Date: 10 October 2006
' Purpose: Allows a multi-line search and replace box in PSPad Editor.
'
'********************************************************************

Const module_name  = "phreplace"
Const module_ver   = "2.0.24"

Sub Init
  addMenuItem "Multiline Search / Replace", "", "ShowMultilineSearch", "Ctrl+Alt+F"
End Sub

'**************************************************
'Purpose: Runs the phreplace add-on which allows 
'         for a multiline search and replace. The 
'         add-on is stored as a dll library, 
'         most of this script is just trying to 
'         register or update the library if needed.
'**************************************************
Sub ShowMultilineSearch 
  Dim editor
  Dim plugin
  Dim pluginPath
  Dim i
  Dim upFolders
  
  On Error Resume Next
  If editorsCount = 0 Then Exit Sub
  
  'Finds the location of phreplace.dll. upFolders sets how many folders up from  
  'the scripts folder the PSPad root folder is located. For me it's up 2 folders 
  '(e.g. \PSPad\Script\VBScript\). But feel free to change this if it's different for you.
  upFolders = 2
  pluginPath = modulePath 
  For i = 1 To upFolders 
    pluginPath = Left(pluginPath, InStrRev(pluginPath, "\", Len(pluginPath) - 1))
  Next
  pluginPath = pluginPath & "phreplace.dll"
  
  If Not LibIsRegistered Then   'If dll isn't registered or isn't latest version
    If Not RegisterDLL(pluginPath, True) Then   'Try to re-register the library.
      CustomError 1, pluginPath
    End If
  End If
  Err.Clear
  Set plugin = CreateObject("phreplace.MultilineSearch")
  If Err.Number <> 0 Then
    CustomError 2, ""
    Exit Sub
  End If
  Set editor = NewEditor()
  'Do we really need to assign anything here?
  editor.assignActiveEditor
  Err.Clear
  'Run phreplace
  plugin.PSPadSearch editor
  If Err.Number <> 0 Then
    CustomError 3, ""
    Exit Sub
  End If
End Sub

'**************************************************
'Purpose: Installs or uninstalls dll's temporarily.
'Inputs:  strFilename: The name of the dll file.
'         blnInstall: If false then it unregisters
'         the dll.
'Returns: True if install succeeds otherwise false.
'**************************************************
Function RegisterDLL(strFilename, blnInstall) 
  Dim shell
  Dim fileSystem
  Dim command
  
  Set shell = CreateObject("Wscript.Shell")
  Set fileSystem = CreateObject("Scripting.FileSystemObject")
  
  command = "regsvr32 /s "
  If Not blnInstall Then
   command = command & "/u "
  End If
  RegisterDLL = False
  If fileSystem.FileExists(strFilename) Then
    shell.Run command & """" & strFilename & """", 1, True
    RegisterDLL = True
  End If
End Function

'**************************************************
'Purpose: Checks that the dll is registered by trying
'         to create the phreplace object. Also checks
'         that the dll version is the same as this 
'         script, if this method fails then it should
'         try to reload the dll.
'**************************************************
Function LibIsRegistered
  Dim plugin
  
  On Error Resume Next
  LibIsRegistered = True
  Set plugin = CreateObject("phreplace.MultilineSearch")
  If Err.Number <> 0 Then
    LibIsRegistered = False
  ElseIf plugin.GetAppVersion <> module_ver Then
    LibIsRegistered = False
  End If
End Function

Sub CustomError(intErr, strErrMessage)
  Select Case intErr
  Case 1: 
    strErrMessage = "Error " & intErr & ": " & "Unable to register library " & strErrMessage
  
  Case 2:
    strErrMessage = "Error " & intErr & ": " & "Unable to start phreplace add-on"
  
  Case 3: 
    strErrMessage = "Error " & intErr & ": " & "There was an error running the phreplace add-on"
  
  Case Else:
    If Len(strErrMessage) = 0 Then
      strErrMessage = "Unspecified Runtime Error"
    End If
   
  End Select
  strErrMessage = strErrMessage & vbNewLine & vbNewLine & "Please check the phreplace.txt file or www.phdesign.com.au for help"
  
  MsgBox strErrMessage, 0, "Search / Replace by phdesign.com.au"
  'Err.Raise intErr, "Search / Replace by phdesign.com.au", strErrMessage, "phreplace.txt"
End Sub

